Clazz.declarePackage("J.api");
(function(){
var c$ = Clazz.declareType(J.api, "JmolAdapterBondIterator", null);
})();
;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
